@@ -6,20 +6,19 @@
 # can be included in any Rcmdr plug-in package to cause the package to load
 # the Rcmdr if it is not already loaded
 
-.First.lib <- function(libname, pkgname){
-    if (!interactive()) return()
-    Rcmdr <- options()$Rcmdr
-    plugins <- Rcmdr$plugins
-    if ((!pkgname %in% plugins) && !getRcmdr("autoRestart")) {
-        Rcmdr$plugins <- c(plugins, pkgname)
-        options(Rcmdr=Rcmdr)
-        closeCommander(ask=FALSE, ask.save=TRUE)
-        Commander()
+.onAttach <- function(libname, pkgname){
+        if (!interactive()) return()
+        Rcmdr <- options()$Rcmdr
+        plugins <- Rcmdr$plugins
+        if ((!pkgname %in% plugins) && !getRcmdr("autoRestart")) {
+                Rcmdr$plugins <- c(plugins, pkgname)
+                options(Rcmdr=Rcmdr)
+                closeCommander(ask=FALSE, ask.save=TRUE)
+                Commander()
         }
-    }
+}
+
 
-    
-   
 
 	ranblockAnova <- function(){
 		initializeDialog(title=gettextRcmdr("Randomized Block Design"))
